==> senior_design_system-0.17.0.tar.gz: lib/themes/senior_theme.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/components/senior_backdrop/senior_backdrop.dart';

import '../components/senior_action_button/senior_action_button_theme.dart';
import '../components/senior_balance/senior_balance_theme.dart';
import '../components/senior_bottom_navigation_bar/senior_bottom_navigation_bar_theme.dart';
import '../components/senior_bottom_sheet/senior_bottom_sheet_theme.dart';
import '../components/senior_button/senior_button_theme.dart';
import '../components/senior_card/senior_card_theme.dart';
import '../components/senior_checkbox/senior_checkbox_theme.dart';
import '../components/senior_colorful_header_structure/senior_colorful_header_structure_theme.dart';
import '../components/senior_contact_book_item/senior_contact_book_item.dart';
import '../components/senior_dropdown_button/senior_dropdown_button.dart';
import '../components/senior_expansion_panel_list/senior_expansion_panel_list.dart';
import '../components/senior_info_card/senior_info_card_theme.dart';
import '../components/senior_loading/senior_loading_theme.dart';
import '../components/senior_menu_list_item/senior_menu_list_item_theme.dart';
import '../components/senior_message_card/senior_message_card_theme.dart';
import '../components/senior_modal/senior_modal.dart';
import '../components/senior_notification_list/senior_notification_list.dart';
import '../components/senior_profile_picture/senior_profile_picture.dart';
import '../components/senior_quotes/senior_quotes.dart';
import '../components/senior_radio_button/senior_radio_button_theme.dart';
import '../components/senior_rating/senior_rating_theme.dart';
import '../components/senior_snackbar/senior_snackbar_theme.dart';
import '../components/senior_square_buttons_menu/senior_square_buttons_menu_theme.dart';
import '../components/senior_switch/senior_switch_theme.dart';
import '../components/senior_tab_bar/senior_tab_bar.dart';
import '../components/senior_text_field/senior_text_field_theme.dart';

class SeniorTheme {
  const SeniorTheme({
    this.actionButtonTheme,
    this.pressActionButtonTheme,
    this.backdropTheme,
    this.balanceTheme,
    this.bottomNavigationBarTheme,
    this.bottomSheetTheme,
    this.primaryButtonTheme,
    this.secondaryButtonTheme,
    this.ghostButtonTheme,
    this.dangerButtonTheme,
    this.cardTheme,
    this.checkboxTheme,
    this.colorfulHeaderStructureTheme,
    this.contactBookItemTheme,
    this.dropdownButtonTheme,
    this.expansionPanelListTheme,
    this.infoCardTheme,
    this.loadingTheme,
    this.menuListItemTheme,
    this.messageCardTheme,
    this.modalTheme,
    this.notificationListTheme,
    this.profilePictureTheme,
    this.quotesTheme,
    this.radioButtonTheme,
    this.ratingTheme,
    this.successSnackbarTheme,
    this.messageSnackbarTheme,
    this.warningSnackbarTheme,
    this.errorSnackbarTheme,
    this.primarySquareButtonsMenuTheme,
    this.secondarySquareButtonsMenuTheme,
    this.ghostSquareButtonsMenuTheme,
    this.switchTheme,
    this.tabBarTheme,
    this.textFieldTheme,
    this.themeData,
  });

  final SeniorActionButtonThemeData? actionButtonTheme;
  final SeniorActionButtonThemeData? pressActionButtonTheme;
  final SeniorBackdropThemeData? backdropTheme;
  final SeniorBalanceThemeData? balanceTheme;
  final SeniorBottomNavigationBarThemeData? bottomNavigationBarTheme;
  final SeniorBottomSheetThemeData? bottomSheetTheme;
  final SeniorButtonThemeData? primaryButtonTheme;
  final SeniorButtonThemeData? secondaryButtonTheme;
  final SeniorButtonThemeData? ghostButtonTheme;
  final SeniorButtonThemeData? dangerButtonTheme;
  final SeniorCardThemeData? cardTheme;
  final SeniorCheckboxThemeData? checkboxTheme;
  final SeniorColorfulHeaderStructureThemeData? colorfulHeaderStructureTheme;
  final SeniorContactBookItemThemeData? contactBookItemTheme;
  final SeniorDropdownButtonThemeData? dropdownButtonTheme;
  final SeniorExpansionPanelListThemeData? expansionPanelListTheme;
  final SeniorInfoCardThemeData? infoCardTheme;
  final SeniorLoadingThemeData? loadingTheme;
  final SeniorMenuListItemThemeData? menuListItemTheme;
  final SeniorMessageCardThemeData? messageCardTheme;
  final SeniorModalThemeData? modalTheme;
  final SeniorNotificationListThemeData? notificationListTheme;
  final SeniorProfilePictureThemeData? profilePictureTheme;
  final SeniorQuotesThemeData? quotesTheme;
  final SeniorRadioButtonThemeData? radioButtonTheme;
  final SeniorRatingThemeData? ratingTheme;
  final SeniorSnackbarThemeData? successSnackbarTheme;
  final SeniorSnackbarThemeData? messageSnackbarTheme;
  final SeniorSnackbarThemeData? warningSnackbarTheme;
  final SeniorSnackbarThemeData? errorSnackbarTheme;
  final SeniorSquareButtonsMenuThemeData? primarySquareButtonsMenuTheme;
  final SeniorSquareButtonsMenuThemeData? secondarySquareButtonsMenuTheme;
  final SeniorSquareButtonsMenuThemeData? ghostSquareButtonsMenuTheme;
  final SeniorSwitchThemeData? switchTheme;
  final SeniorTabBarThemeData? tabBarTheme;
  final SeniorTextFieldThemeData? textFieldTheme;
  final ThemeData? themeData;

  SeniorTheme copyWith({
    SeniorActionButtonThemeData? actionButtonTheme,
    SeniorActionButtonThemeData? pressActionButtonTheme,
    SeniorBackdropThemeData? backdropTheme,
    SeniorBalanceThemeData? balanceTheme,
    SeniorBottomNavigationBarThemeData? bottomNavigationBarTheme,
    SeniorBottomSheetThemeData? bottomSheetTheme,
    SeniorButtonThemeData? primaryButtonTheme,
    SeniorButtonThemeData? secondaryButtonTheme,
    SeniorButtonThemeData? ghostButtonTheme,
    SeniorButtonThemeData? dangerButtonTheme,
    SeniorCardThemeData? cardTheme,
    SeniorCheckboxThemeData? checkboxTheme,
    SeniorColorfulHeaderStructureThemeData? colorfulHeaderStructureTheme,
    SeniorContactBookItemThemeData? contactBookItemTheme,
    SeniorDropdownButtonThemeData? dropdownButtonTheme,
    SeniorExpansionPanelListThemeData? expansionPanelListTheme,
    SeniorInfoCardThemeData? infoCardTheme,
    SeniorLoadingThemeData? loadingTheme,
    SeniorMenuListItemThemeData? menuListItemTheme,
    SeniorMessageCardThemeData? messageCardTheme,
    SeniorModalThemeData? modalTheme,
    SeniorNotificationListThemeData? notificationListTheme,
    SeniorProfilePictureThemeData? profilePictureTheme,
    SeniorQuotesThemeData? quotesTheme,
    SeniorRadioButtonThemeData? radioButtonTheme,
    SeniorRatingThemeData? ratingTheme,
    SeniorSnackbarThemeData? successSnackbarTheme,
    SeniorSnackbarThemeData? messageSnackbarTheme,
    SeniorSnackbarThemeData? warningSnackbarTheme,
    SeniorSnackbarThemeData? errorSnackbarTheme,
    SeniorSquareButtonsMenuThemeData? primarySquareButtonsMenuTheme,
    SeniorSquareButtonsMenuThemeData? secondarySquareButtonsMenuTheme,
    SeniorSquareButtonsMenuThemeData? ghostSquareButtonsMenuTheme,
    SeniorSwitchThemeData? switchTheme,
    SeniorTabBarThemeData? tabBarTheme,
    SeniorTextFieldThemeData? textFieldTheme,
    ThemeData? themeData,
  }) {
    return SeniorTheme(
      actionButtonTheme: actionButtonTheme ?? this.actionButtonTheme,
      pressActionButtonTheme: pressActionButtonTheme ?? this.pressActionButtonTheme,
      backdropTheme: backdropTheme ?? this.backdropTheme,
      balanceTheme: balanceTheme ?? this.balanceTheme,
      bottomNavigationBarTheme: bottomNavigationBarTheme ?? this.bottomNavigationBarTheme,
      bottomSheetTheme: bottomSheetTheme ?? this.bottomSheetTheme,
      primaryButtonTheme: primaryButtonTheme ?? this.primaryButtonTheme,
      secondaryButtonTheme: secondaryButtonTheme ?? this.secondaryButtonTheme,
      ghostButtonTheme: ghostButtonTheme ?? this.ghostButtonTheme,
      dangerButtonTheme: dangerButtonTheme ?? this.dangerButtonTheme,
      cardTheme: cardTheme ?? this.cardTheme,
      checkboxTheme: checkboxTheme ?? this.checkboxTheme,
      colorfulHeaderStructureTheme: colorfulHeaderStructureTheme ?? this.colorfulHeaderStructureTheme,
      contactBookItemTheme: contactBookItemTheme ?? this.contactBookItemTheme,
      dropdownButtonTheme: dropdownButtonTheme ?? this.dropdownButtonTheme,
      expansionPanelListTheme: expansionPanelListTheme ?? this.expansionPanelListTheme,
      infoCardTheme: infoCardTheme ?? this.infoCardTheme,
      loadingTheme: loadingTheme ?? this.loadingTheme,
      menuListItemTheme: menuListItemTheme ?? this.menuListItemTheme,
      messageCardTheme: messageCardTheme ?? this.messageCardTheme,
      modalTheme: modalTheme ?? this.modalTheme,
      notificationListTheme: notificationListTheme ?? this.notificationListTheme,
      profilePictureTheme: profilePictureTheme ?? this.profilePictureTheme,
      quotesTheme: quotesTheme ?? this.quotesTheme,
      radioButtonTheme: radioButtonTheme ?? this.radioButtonTheme,
      ratingTheme: ratingTheme ?? this.ratingTheme,
      successSnackbarTheme: successSnackbarTheme ?? this.successSnackbarTheme,
      messageSnackbarTheme: messageSnackbarTheme ?? this.messageSnackbarTheme,
      warningSnackbarTheme: warningSnackbarTheme ?? this.warningSnackbarTheme,
      errorSnackbarTheme: errorSnackbarTheme ?? this.errorSnackbarTheme,
      primarySquareButtonsMenuTheme: primarySquareButtonsMenuTheme ?? this.primarySquareButtonsMenuTheme,
      secondarySquareButtonsMenuTheme: secondarySquareButtonsMenuTheme ?? this.secondarySquareButtonsMenuTheme,
      ghostSquareButtonsMenuTheme: ghostSquareButtonsMenuTheme ?? this.ghostSquareButtonsMenuTheme,
      switchTheme: switchTheme ?? this.switchTheme,
      tabBarTheme: tabBarTheme ?? this.tabBarTheme,
      textFieldTheme: textFieldTheme ?? this.textFieldTheme,
      themeData: themeData ?? this.themeData,
    );
  }
}

==> senior_design_system-0.21.4.tar.gz: lib/themes/senior_theme.dart <==
import 'package:flutter/material.dart';
import 'package:senior_design_system/components/senior_pin_code_field/seenior_pin_code_field.dart';

import '../components/senior_action_button/senior_action_button_theme.dart';
import '../components/senior_backdrop/senior_backdrop.dart';
import '../components/senior_balance/senior_balance_theme.dart';
import '../components/senior_bottom_navigation_bar/senior_bottom_navigation_bar_theme.dart';
import '../components/senior_bottom_sheet/senior_bottom_sheet_theme.dart';
import '../components/senior_button/senior_button_theme.dart';
import '../components/senior_card/senior_card_theme.dart';
import '../components/senior_checkbox/senior_checkbox_theme.dart';
import '../components/senior_colorful_header_structure/senior_colorful_header_structure_theme.dart';
import '../components/senior_contact_book_item/senior_contact_book_item.dart';
import '../components/senior_drawer/senior_drawer.dart';
import '../components/senior_dropdown_button/senior_dropdown_button.dart';
import '../components/senior_expansion_panel_list/senior_expansion_panel_list.dart';
import '../components/senior_gradient_icon/senior_gradient_icon.dart';
import '../components/senior_info_card/senior_info_card_theme.dart';
import '../components/senior_list/senior_list.dart';
import '../components/senior_loading/senior_loading_theme.dart';
import '../components/senior_menu_list_item/senior_menu_list_item_theme.dart';
import '../components/senior_message_card/senior_message_card_theme.dart';
import '../components/senior_modal/senior_modal.dart';
import '../components/senior_notification_list/senior_notification_list.dart';
import '../components/senior_profile_picture/senior_profile_picture.dart';
import '../components/senior_progress_bar/senior_progress_bar.dart';
import '../components/senior_quotes/senior_quotes.dart';
import '../components/senior_radio_button/senior_radio_button_theme.dart';
import '../components/senior_rating/senior_rating_theme.dart';
import '../components/senior_snackbar/senior_snackbar_theme.dart';
import '../components/senior_square_buttons_menu/senior_square_buttons_menu_theme.dart';
import '../components/senior_state_page/senior_state_page.dart';
import '../components/senior_switch/senior_switch_theme.dart';
import '../components/senior_tab_bar/senior_tab_bar.dart';
import '../components/senior_text_field/senior_text_field_theme.dart';
import '../components/senior_timeline/senior_timeline.dart';

class SeniorTheme {
  const SeniorTheme({
    this.actionButtonTheme,
    this.pressActionButtonTheme,
    this.backdropTheme,
    this.balanceTheme,
    this.bottomNavigationBarTheme,
    this.bottomSheetTheme,
    this.primaryButtonTheme,
    this.secondaryButtonTheme,
    this.ghostButtonTheme,
    this.dangerButtonTheme,
    this.cardTheme,
    this.checkboxTheme,
    this.colorfulHeaderStructureTheme,
    this.contactBookItemTheme,
    this.drawerTheme,
    this.dropdownButtonTheme,
    this.expansionPanelListTheme,
    this.gradientIconTheme,
    this.infoCardTheme,
    this.listTheme,
    this.loadingTheme,
    this.menuListItemTheme,
    this.messageCardTheme,
    this.modalTheme,
    this.notificationListTheme,
    this.pinCodeFieldTheme,
    this.profilePictureTheme,
    this.progressBarTheme,
    this.quotesTheme,
    this.radioButtonTheme,
    this.ratingTheme,
    this.successSnackbarTheme,
    this.messageSnackbarTheme,
    this.warningSnackbarTheme,
    this.errorSnackbarTheme,
    this.emphasisSquareButtonsMenuTheme,
    this.emphasisNegativeSquareButtonsMenuTheme,
    this.neutralSquareButtonsMenuTheme,
    this.neutralNegativeSquareButtonsMenuTheme,
    this.ghostSquareButtonsMenuTheme,
    this.ghostNegativeSquareButtonsMenuTheme,    
    this.statePageTheme,
    this.switchTheme,
    this.tabBarTheme,
    this.textFieldTheme,
    this.timelineTheme,
    this.themeData,
  });

  final SeniorActionButtonThemeData? actionButtonTheme;
  final SeniorActionButtonThemeData? pressActionButtonTheme;
  final SeniorBackdropThemeData? backdropTheme;
  final SeniorBalanceThemeData? balanceTheme;
  final SeniorBottomNavigationBarThemeData? bottomNavigationBarTheme;
  final SeniorBottomSheetThemeData? bottomSheetTheme;
  final SeniorButtonThemeData? primaryButtonTheme;
  final SeniorButtonThemeData? secondaryButtonTheme;
  final SeniorButtonThemeData? ghostButtonTheme;
  final SeniorButtonThemeData? dangerButtonTheme;
  final SeniorCardThemeData? cardTheme;
  final SeniorCheckboxThemeData? checkboxTheme;
  final SeniorColorfulHeaderStructureThemeData? colorfulHeaderStructureTheme;
  final SeniorContactBookItemThemeData? contactBookItemTheme;
  final SeniorDrawerThemeData? drawerTheme;
  final SeniorDropdownButtonThemeData? dropdownButtonTheme;
  final SeniorExpansionPanelListThemeData? expansionPanelListTheme;
  final SeniorGradientIconThemeData? gradientIconTheme;
  final SeniorInfoCardThemeData? infoCardTheme;
  final SeniorListThemeData? listTheme;
  final SeniorLoadingThemeData? loadingTheme;
  final SeniorMenuListItemThemeData? menuListItemTheme;
  final SeniorMessageCardThemeData? messageCardTheme;
  final SeniorModalThemeData? modalTheme;
  final SeniorNotificationListThemeData? notificationListTheme;
  final SeniorPinCodeFieldThemeData? pinCodeFieldTheme;
  final SeniorProfilePictureThemeData? profilePictureTheme;
  final SeniorProgressBarThemeData? progressBarTheme;
  final SeniorQuotesThemeData? quotesTheme;
  final SeniorRadioButtonThemeData? radioButtonTheme;
  final SeniorRatingThemeData? ratingTheme;
  final SeniorSnackbarThemeData? successSnackbarTheme;
  final SeniorSnackbarThemeData? messageSnackbarTheme;
  final SeniorSnackbarThemeData? warningSnackbarTheme;
  final SeniorSnackbarThemeData? errorSnackbarTheme;
  final SeniorSquareButtonsMenuThemeData? emphasisSquareButtonsMenuTheme;
  final SeniorSquareButtonsMenuThemeData? emphasisNegativeSquareButtonsMenuTheme;
  final SeniorSquareButtonsMenuThemeData? neutralSquareButtonsMenuTheme;
  final SeniorSquareButtonsMenuThemeData? neutralNegativeSquareButtonsMenuTheme;
  final SeniorSquareButtonsMenuThemeData? ghostSquareButtonsMenuTheme;
  final SeniorSquareButtonsMenuThemeData? ghostNegativeSquareButtonsMenuTheme;  
  final SeniorStatePageThemeData? statePageTheme;
  final SeniorSwitchThemeData? switchTheme;
  final SeniorTabBarThemeData? tabBarTheme;
  final SeniorTextFieldThemeData? textFieldTheme;
  final SeniorTimelineThemeData? timelineTheme;
  final ThemeData? themeData;

  SeniorTheme copyWith({
    SeniorActionButtonThemeData? actionButtonTheme,
    SeniorActionButtonThemeData? pressActionButtonTheme,
    SeniorBackdropThemeData? backdropTheme,
    SeniorBalanceThemeData? balanceTheme,
    SeniorBottomNavigationBarThemeData? bottomNavigationBarTheme,
    SeniorBottomSheetThemeData? bottomSheetTheme,
    SeniorButtonThemeData? primaryButtonTheme,
    SeniorButtonThemeData? secondaryButtonTheme,
    SeniorButtonThemeData? ghostButtonTheme,
    SeniorButtonThemeData? dangerButtonTheme,
    SeniorCardThemeData? cardTheme,
    SeniorCheckboxThemeData? checkboxTheme,
    SeniorColorfulHeaderStructureThemeData? colorfulHeaderStructureTheme,
    SeniorContactBookItemThemeData? contactBookItemTheme,
    SeniorDropdownButtonThemeData? dropdownButtonTheme,
    SeniorDrawerThemeData? drawerTheme,
    SeniorExpansionPanelListThemeData? expansionPanelListTheme,
    SeniorGradientIconThemeData? gradientIconTheme,
    SeniorInfoCardThemeData? infoCardTheme,
    SeniorListThemeData? listTheme,
    SeniorLoadingThemeData? loadingTheme,
    SeniorMenuListItemThemeData? menuListItemTheme,
    SeniorMessageCardThemeData? messageCardTheme,
    SeniorModalThemeData? modalTheme,
    SeniorNotificationListThemeData? notificationListTheme,
    SeniorPinCodeFieldThemeData? pinCodeFieldTheme,
    SeniorProfilePictureThemeData? profilePictureTheme,
    SeniorProgressBarThemeData? progressBarTheme,
    SeniorQuotesThemeData? quotesTheme,
    SeniorRadioButtonThemeData? radioButtonTheme,
    SeniorRatingThemeData? ratingTheme,
    SeniorSnackbarThemeData? successSnackbarTheme,
    SeniorSnackbarThemeData? messageSnackbarTheme,
    SeniorSnackbarThemeData? warningSnackbarTheme,
    SeniorSnackbarThemeData? errorSnackbarTheme,
    SeniorSquareButtonsMenuThemeData? emphasisSquareButtonsMenuTheme,
    SeniorSquareButtonsMenuThemeData? emphasisNegativeSquareButtonsMenuTheme,
    SeniorSquareButtonsMenuThemeData? neutralSquareButtonsMenuTheme,
    SeniorSquareButtonsMenuThemeData? neutralNegativeSquareButtonsMenuTheme,
    SeniorSquareButtonsMenuThemeData? ghostSquareButtonsMenuTheme,
    SeniorSquareButtonsMenuThemeData? ghostNegativeSquareButtonsMenuTheme,    
    SeniorStatePageThemeData? statePageTheme,
    SeniorSwitchThemeData? switchTheme,
    SeniorTabBarThemeData? tabBarTheme,
    SeniorTextFieldThemeData? textFieldTheme,
    SeniorTimelineThemeData? timelineTheme,
    ThemeData? themeData,
  }) {
    return SeniorTheme(
      actionButtonTheme: actionButtonTheme ?? this.actionButtonTheme,
      pressActionButtonTheme: pressActionButtonTheme ?? this.pressActionButtonTheme,
      backdropTheme: backdropTheme ?? this.backdropTheme,
      balanceTheme: balanceTheme ?? this.balanceTheme,
      bottomNavigationBarTheme: bottomNavigationBarTheme ?? this.bottomNavigationBarTheme,
      bottomSheetTheme: bottomSheetTheme ?? this.bottomSheetTheme,
      primaryButtonTheme: primaryButtonTheme ?? this.primaryButtonTheme,
      secondaryButtonTheme: secondaryButtonTheme ?? this.secondaryButtonTheme,
      ghostButtonTheme: ghostButtonTheme ?? this.ghostButtonTheme,
      dangerButtonTheme: dangerButtonTheme ?? this.dangerButtonTheme,
      cardTheme: cardTheme ?? this.cardTheme,
      checkboxTheme: checkboxTheme ?? this.checkboxTheme,
      colorfulHeaderStructureTheme: colorfulHeaderStructureTheme ?? this.colorfulHeaderStructureTheme,
      contactBookItemTheme: contactBookItemTheme ?? this.contactBookItemTheme,
      drawerTheme: drawerTheme ?? this.drawerTheme,
      dropdownButtonTheme: dropdownButtonTheme ?? this.dropdownButtonTheme,
      expansionPanelListTheme: expansionPanelListTheme ?? this.expansionPanelListTheme,
      gradientIconTheme: gradientIconTheme ?? this.gradientIconTheme,
      infoCardTheme: infoCardTheme ?? this.infoCardTheme,
      listTheme: listTheme ?? this.listTheme,
      loadingTheme: loadingTheme ?? this.loadingTheme,
      menuListItemTheme: menuListItemTheme ?? this.menuListItemTheme,
      messageCardTheme: messageCardTheme ?? this.messageCardTheme,
      modalTheme: modalTheme ?? this.modalTheme,
      notificationListTheme: notificationListTheme ?? this.notificationListTheme,
      pinCodeFieldTheme: pinCodeFieldTheme ?? this.pinCodeFieldTheme,
      profilePictureTheme: profilePictureTheme ?? this.profilePictureTheme,
      progressBarTheme: progressBarTheme ?? this.progressBarTheme,
      quotesTheme: quotesTheme ?? this.quotesTheme,
      radioButtonTheme: radioButtonTheme ?? this.radioButtonTheme,
      ratingTheme: ratingTheme ?? this.ratingTheme,
      successSnackbarTheme: successSnackbarTheme ?? this.successSnackbarTheme,
      messageSnackbarTheme: messageSnackbarTheme ?? this.messageSnackbarTheme,
      warningSnackbarTheme: warningSnackbarTheme ?? this.warningSnackbarTheme,
      errorSnackbarTheme: errorSnackbarTheme ?? this.errorSnackbarTheme,
      emphasisSquareButtonsMenuTheme: emphasisSquareButtonsMenuTheme ?? this.emphasisSquareButtonsMenuTheme,
      emphasisNegativeSquareButtonsMenuTheme: emphasisNegativeSquareButtonsMenuTheme ?? this.emphasisNegativeSquareButtonsMenuTheme,
      neutralSquareButtonsMenuTheme: neutralSquareButtonsMenuTheme ?? this.neutralSquareButtonsMenuTheme,
      neutralNegativeSquareButtonsMenuTheme: neutralNegativeSquareButtonsMenuTheme ?? this.neutralNegativeSquareButtonsMenuTheme,
      ghostSquareButtonsMenuTheme: ghostSquareButtonsMenuTheme ?? this.ghostSquareButtonsMenuTheme,
      ghostNegativeSquareButtonsMenuTheme: ghostNegativeSquareButtonsMenuTheme ?? this.ghostNegativeSquareButtonsMenuTheme,
      statePageTheme: statePageTheme ?? this.statePageTheme,
      switchTheme: switchTheme ?? this.switchTheme,
      tabBarTheme: tabBarTheme ?? this.tabBarTheme,
      textFieldTheme: textFieldTheme ?? this.textFieldTheme,
      timelineTheme: timelineTheme ?? this.timelineTheme,
      themeData: themeData ?? this.themeData,
    );
  }
}
